# If the optional region is true, we create the region with the aws optional region provider
resource "aws_sns_topic_subscription" "optional_region_sub" {
  count = var.optional_region ? 1 : 0
  topic_arn              = var.topic_arn
  protocol               = var.protocol
  endpoint               = var.endpoint
  endpoint_auto_confirms = var.endpoint_auto_confirms
  filter_policy          = jsonencode(var.filter_policy)
  raw_message_delivery   = var.raw_message_delivery
  provider               = aws.optional_region
}
# If the optional region is false, we make the default subscription
resource "aws_sns_topic_subscription" "sub" {
  count = var.optional_region ? 0 : 1
  topic_arn              = var.topic_arn
  protocol               = var.protocol
  endpoint               = var.endpoint
  endpoint_auto_confirms = var.endpoint_auto_confirms
  filter_policy          = jsonencode(var.filter_policy)
  raw_message_delivery   = var.raw_message_delivery
}

resource "aws_lambda_permission" "allow_subscription" {
  count         = length(var.lambda_arn) > 0 ? 1 : 0
  statement_id  = "AllowExecutionFromSNS"
  action        = "lambda:InvokeFunction"
  function_name = var.lambda_arn
  principal     = "sns.amazonaws.com"
  source_arn    = var.topic_arn
}
